@@ -210,7 +210,7 @@ SEXP dsCMatrix_matrix_solve(SEXP a, SEXP b)
 SEXP dsCMatrix_to_dgTMatrix(SEXP x)
 {
     CHM_SP A = AS_CHM_SP__(x);
-    CHM_SP Afull = cholmod_l_copy(A, /*stype*/ 0, /*mode*/ 1, &c);
+    CHM_SP Afull = cholmod_l_copy(A, /*stype*/ 0, /*mode*/ CHOLMOD_REAL, &c);
     CHM_TR At = cholmod_l_sparse_to_triplet(Afull, &c);
     R_CheckStack();
 
